# qudi-iqo-modules
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)

---
A collection of qudi measurement modules originally developed for experiments on color centers in 
semiconductor materials.



## Installation
For installation instructions please refer to our
[iqo-modules installation guide](https://github.com/Ulm-IQO/qudi-iqo-modules/blob/main/docs/installation_guide.md).


## More information
The best starting point for further researching the qudi documentation is the [readme file](https://github.com/Ulm-IQO/qudi-core) of the qudi-core repo.

## Forum
For questions concerning qudi or the iqo-modules, there is a [forum](https://github.com/Ulm-IQO/qudi-core/discussions) to discuss with the qudi community. Feel free to ask!
If you found a bug and located it already, please note GitHub's [issue tracking](https://github.com/Ulm-IQO/qudi-iqo-modules/issues) feature.

## Copyright
Check [AUTHORS.md](AUTHORS.md) for a list of authors and the git history for their individual
contributions.
